@@ -17,11 +17,11 @@ const webpack = require('webpack');
 
 module.exports = function(config) {
   // bundler to test: webpack, browserify
-  var bundler = process.env.BUNDLER || 'webpack';
+  const bundler = process.env.BUNDLER || 'webpack';
 
-  var frameworks = ['mocha', 'server-side'];
+  const frameworks = ['mocha', 'server-side'];
   // main bundle preprocessors
-  var preprocessors = ['babel'];
+  const preprocessors = ['babel'];
 
   if(bundler === 'browserify') {
     frameworks.push(bundler);
@@ -39,7 +39,7 @@ module.exports = function(config) {
 
     // frameworks to use
     // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
-    frameworks: frameworks,
+    frameworks,
 
     // list of files / patterns to load in the browser
     files: [
@@ -54,7 +54,8 @@ module.exports = function(config) {
     ],
 
     // preprocess matching files before serving them to the browser
-    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
+    // available preprocessors:
+    // https://npmjs.org/browse/keyword/karma-preprocessor
     preprocessors: {
       //'tests/*.js': ['webpack', 'babel'] //preprocessors
       'tests/*.js': preprocessors
@@ -127,14 +128,17 @@ module.exports = function(config) {
     colors: true,
 
     // level of logging
-    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
+    // possible values: config.LOG_DISABLE || config.LOG_ERROR ||
+    // config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
     logLevel: config.LOG_INFO,
 
-    // enable / disable watching file and executing tests whenever any file changes
+    // enable / disable watching file and executing tests whenever any file
+    // changes
     autoWatch: false,
 
     // start these browsers
-    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
+    // available browser launchers:
+    // https://npmjs.org/browse/keyword/karma-launcher
     //browsers: ['ChromeHeadless', 'Chrome', 'Firefox', 'Safari'],
     browsers: ['ChromeHeadless'],
 
