@@ -32,6 +32,7 @@ const {
 
 const {
   addValue: _addValue,
+  asArray: _asArray,
   compareShortestLeast: _compareShortestLeast
 } = require('./util');
 
@@ -167,7 +168,7 @@ api.compact = ({
 
       // compact @id and @type(s)
       if(expandedProperty === '@id' || expandedProperty === '@type') {
-        let compactedValue = [].concat(expandedValue).map(
+        let compactedValue = _asArray(expandedValue).map(
           expandedIri => api.compactIri({
             activeCtx,
             iri: expandedIri,
@@ -491,17 +492,17 @@ api.compact = ({
               vocab: true
             });
             let types;
-            [key, ...types] = [].concat(compactedItem[typeKey] || []);
+            [key, ...types] = _asArray(compactedItem[typeKey] || []);
             switch(types.length) {
-            case 0:
-              delete compactedItem[typeKey];
-              break;
-            case 1:
-              compactedItem[typeKey] = types[0];
-              break;
-            default:
-              compactedItem[typeKey] = types;
-              break;
+              case 0:
+                delete compactedItem[typeKey];
+                break;
+              case 1:
+                compactedItem[typeKey] = types[0];
+                break;
+              default:
+                compactedItem[typeKey] = types;
+                break;
             }
           }
 
