@@ -21,6 +21,11 @@ const {
   parse: parseUrl
 } = require('./url');
 
+const {
+  asArray: _asArray,
+  compareShortestLeast: _compareShortestLeast
+} = require('./util');
+
 const MAX_CONTEXT_URLS = 10;
 
 const INITIAL_CONTEXT_CACHE = new Map();
@@ -210,7 +215,7 @@ api.createTermDefinition = (activeCtx, localCtx, term, defined) => {
     throw new JsonLdError(
       'Cyclical context definition detected.',
       'jsonld.CyclicalContext',
-      {code: 'cyclic IRI mapping', context: localCtx, term: term});
+      {code: 'cyclic IRI mapping', context: localCtx, term});
   }
 
   // now defining term
@@ -220,7 +225,7 @@ api.createTermDefinition = (activeCtx, localCtx, term, defined) => {
     throw new JsonLdError(
       'Invalid JSON-LD syntax; keywords cannot be overridden.',
       'jsonld.SyntaxError',
-      {code: 'keyword redefinition', context: localCtx, term: term});
+      {code: 'keyword redefinition', context: localCtx, term});
   }
 
   if(term === '') {
@@ -367,7 +372,7 @@ api.createTermDefinition = (activeCtx, localCtx, term, defined) => {
         throw new JsonLdError(
           'Invalid JSON-LD syntax; @context terms must define an @id.',
           'jsonld.SyntaxError',
-          {code: 'invalid IRI mapping', context: localCtx, term: term});
+          {code: 'invalid IRI mapping', context: localCtx, term});
       }
       // prepend vocab to term
       mapping['@id'] = activeCtx['@vocab'] + term;
@@ -631,7 +636,7 @@ api.expandIri = (activeCtx, value, relativeTo, localCtx, defined) => {
  *
  * @return the initial context.
  */
-api.getInitialContext = (options) => {
+api.getInitialContext = options => {
   const base = parseUrl(options.base || '');
   const key = JSON.stringify({base, processingMode: options.processingMode});
   const cached = INITIAL_CONTEXT_CACHE.get(key);
@@ -681,7 +686,7 @@ api.getInitialContext = (options) => {
     // create term selections for each mapping in the context, ordered by
     // shortest and then lexicographically least
     const mappings = activeCtx.mappings;
-    const terms = Object.keys(mappings).sort(util.compareShortestLeast);
+    const terms = Object.keys(mappings).sort(_compareShortestLeast);
     for(let i = 0; i < terms.length; ++i) {
       const term = terms[i];
       const mapping = mappings[term];
@@ -693,7 +698,7 @@ api.getInitialContext = (options) => {
       container = [].concat(container).sort().join('');
 
       // iterate over every IRI in the mapping
-      const ids = [].concat(mapping['@id']);
+      const ids = _asArray(mapping['@id']);
       for(let ii = 0; ii < ids.length; ++ii) {
         const iri = ids[ii];
         let entry = inverse[iri];
@@ -706,7 +711,7 @@ api.getInitialContext = (options) => {
           if(!isKeyword && !mapping._termHasColon) {
             // init IRI to term map and fast CURIE prefixes
             irisToTerms[iri] = [term];
-            const fastCurieEntry = {iri: iri, terms: irisToTerms[iri]};
+            const fastCurieEntry = {iri, terms: irisToTerms[iri]};
             if(iri[0] in fastCurieMap) {
               fastCurieMap[iri[0]].push(fastCurieEntry);
             } else {
@@ -914,30 +919,30 @@ api.isKeyword = v => {
     return false;
   }
   switch(v) {
-  case '@base':
-  case '@container':
-  case '@context':
-  case '@default':
-  case '@embed':
-  case '@explicit':
-  case '@graph':
-  case '@id':
-  case '@index':
-  case '@language':
-  case '@list':
-  case '@nest':
-  case '@none':
-  case '@omitDefault':
-  case '@prefix':
-  case '@preserve':
-  case '@requireAll':
-  case '@reverse':
-  case '@set':
-  case '@type':
-  case '@value':
-  case '@version':
-  case '@vocab':
-    return true;
+    case '@base':
+    case '@container':
+    case '@context':
+    case '@default':
+    case '@embed':
+    case '@explicit':
+    case '@graph':
+    case '@id':
+    case '@index':
+    case '@language':
+    case '@list':
+    case '@nest':
+    case '@none':
+    case '@omitDefault':
+    case '@prefix':
+    case '@preserve':
+    case '@requireAll':
+    case '@reverse':
+    case '@set':
+    case '@type':
+    case '@value':
+    case '@version':
+    case '@vocab':
+      return true;
   }
   return false;
 };
@@ -962,6 +967,9 @@ async function _retrieveContextUrls(input, options) {
     // find all URLs in the given document
     const urls = new Map();
     _findContextUrls(doc, urls, false, options.base);
+    if(urls.size === 0) {
+      return;
+    }
 
     // queue all unretrieved URLs
     const queue = [...urls.keys()].filter(u => urls.get(u) === false);
