@@ -31,8 +31,9 @@ const {
 
 const {
   addValue: _addValue,
-  validateTypeValue: _validateTypeValue,
-  getValues: _getValues
+  asArray: _asArray,
+  getValues: _getValues,
+  validateTypeValue: _validateTypeValue
 } = require('./util');
 
 const api = {};
@@ -157,7 +158,11 @@ api.expand = ({
     const expandedProperty = _expandIri(activeCtx, key, {vocab: true});
     if(expandedProperty === '@type') {
       // set scopped contexts from @type
-      const types = [].concat(element[key]).sort();
+      // avoid sorting if possible
+      const value = element[key];
+      const types =
+        Array.isArray(value) ?
+          (value.length > 1 ? value.slice().sort() : value) : [value];
       for(const type of types) {
         const ctx = _getContextValue(activeCtx, type, '@context');
         if(ctx) {
@@ -212,7 +217,7 @@ api.expand = ({
         'which can be "@type" or "@language".',
         'jsonld.SyntaxError', {code: 'invalid value object', element: rval});
     }
-    const values = rval['@value'] === null ? [] : [].concat(rval['@value']);
+    const values = rval['@value'] === null ? [] : _asArray(rval['@value']);
     const types = _getValues(rval, '@type');
 
     // drop null @values unless custom mapped
@@ -373,7 +378,7 @@ function _expandObject({
         throw new JsonLdError(
           'Invalid JSON-LD syntax; a keyword cannot be used as a @reverse ' +
           'property.', 'jsonld.SyntaxError',
-          {code: 'invalid reverse property map', value: value});
+          {code: 'invalid reverse property map', value});
       }
       if(expandedProperty in expandedParent) {
         throw new JsonLdError(
@@ -389,7 +394,7 @@ function _expandObject({
         if(!options.isFrame) {
           throw new JsonLdError(
             'Invalid JSON-LD syntax; "@id" value must a string.',
-            'jsonld.SyntaxError', {code: 'invalid @id value', value: value});
+            'jsonld.SyntaxError', {code: 'invalid @id value', value});
         }
         if(_isObject(value)) {
           // empty object is a wildcard
@@ -397,26 +402,26 @@ function _expandObject({
             throw new JsonLdError(
               'Invalid JSON-LD syntax; "@id" value an empty object or array ' +
               'of strings, if framing',
-              'jsonld.SyntaxError', {code: 'invalid @id value', value: value});
+              'jsonld.SyntaxError', {code: 'invalid @id value', value});
           }
         } else if(_isArray(value)) {
           if(!value.every(v => _isString(v))) {
             throw new JsonLdError(
               'Invalid JSON-LD syntax; "@id" value an empty object or array ' +
               'of strings, if framing',
-              'jsonld.SyntaxError', {code: 'invalid @id value', value: value});
+              'jsonld.SyntaxError', {code: 'invalid @id value', value});
           }
         } else {
           throw new JsonLdError(
             'Invalid JSON-LD syntax; "@id" value an empty object or array ' +
             'of strings, if framing',
-            'jsonld.SyntaxError', {code: 'invalid @id value', value: value});
+            'jsonld.SyntaxError', {code: 'invalid @id value', value});
         }
       }
 
       _addValue(
         expandedParent, '@id',
-        [].concat(value).map(v =>
+        _asArray(value).map(v =>
           _isString(v) ? _expandIri(activeCtx, v, {base: true}) : v),
         {propertyIsArray: options.isFrame});
       continue;
@@ -426,7 +431,7 @@ function _expandObject({
       _validateTypeValue(value);
       _addValue(
         expandedParent, '@type',
-        [].concat(value).map(v =>
+        _asArray(value).map(v =>
           _isString(v) ?
             _expandIri(activeCtx, v, {base: true, vocab: true}) : v),
         {propertyIsArray: options.isFrame});
@@ -439,7 +444,7 @@ function _expandObject({
       throw new JsonLdError(
         'Invalid JSON-LD syntax; "@graph" value must not be an ' +
         'object or an array.',
-        'jsonld.SyntaxError', {code: 'invalid @graph value', value: value});
+        'jsonld.SyntaxError', {code: 'invalid @graph value', value});
     }
 
     // @value must not be an object or an array (unless framing)
@@ -449,7 +454,7 @@ function _expandObject({
           'Invalid JSON-LD syntax; "@value" value must not be an ' +
           'object or an array.',
           'jsonld.SyntaxError',
-          {code: 'invalid value object value', value: value});
+          {code: 'invalid value object value', value});
       }
 
       _addValue(
@@ -467,10 +472,10 @@ function _expandObject({
         throw new JsonLdError(
           'Invalid JSON-LD syntax; "@language" value must be a string.',
           'jsonld.SyntaxError',
-          {code: 'invalid language-tagged string', value: value});
+          {code: 'invalid language-tagged string', value});
       }
       // ensure language value is lowercase
-      value = [].concat(value).map(v => _isString(v) ? v.toLowerCase() : v);
+      value = _asArray(value).map(v => _isString(v) ? v.toLowerCase() : v);
 
       _addValue(
         expandedParent, '@language', value, {propertyIsArray: options.isFrame});
@@ -483,7 +488,7 @@ function _expandObject({
         throw new JsonLdError(
           'Invalid JSON-LD syntax; "@index" value must be a string.',
           'jsonld.SyntaxError',
-          {code: 'invalid @index value', value: value});
+          {code: 'invalid @index value', value});
       }
       _addValue(expandedParent, '@index', value);
       continue;
@@ -494,7 +499,7 @@ function _expandObject({
       if(!_isObject(value)) {
         throw new JsonLdError(
           'Invalid JSON-LD syntax; "@reverse" value must be an object.',
-          'jsonld.SyntaxError', {code: 'invalid @reverse value', value: value});
+          'jsonld.SyntaxError', {code: 'invalid @reverse value', value});
       }
 
       expandedValue = api.expand({
@@ -639,7 +644,7 @@ function _expandObject({
         parent: element,
         options,
         insideList,
-        key: key,
+        key,
         expandedParent
       });
       if(expandedValue === undefined) {
@@ -650,10 +655,8 @@ function _expandObject({
     // convert expanded value to @list if container specifies it
     if(expandedProperty !== '@list' && !_isList(expandedValue) &&
       container.includes('@list')) {
-      // ensure expanded value is an array
-      expandedValue = (_isArray(expandedValue) ?
-        expandedValue : [expandedValue]);
-      expandedValue = {'@list': expandedValue};
+      // ensure expanded value in @list is an array
+      expandedValue = {'@list': _asArray(expandedValue)};
     }
 
     // convert expanded value to @graph if container specifies it
@@ -662,8 +665,8 @@ function _expandObject({
     if(container.includes('@graph') &&
       !container.some(key => key === '@id' || key === '@index')) {
       // ensure expanded values are arrays
-      expandedValue = [].concat(expandedValue)
-        .map(v => _isGraph(v) ? v : {'@graph': [].concat(v)});
+      expandedValue = _asArray(expandedValue)
+        .map(v => _isGraph(v) ? v : {'@graph': _asArray(v)});
     }
 
     // FIXME: can this be merged with code above to simplify?
@@ -671,9 +674,7 @@ function _expandObject({
     if(termCtx.mappings[key] && termCtx.mappings[key].reverse) {
       const reverseMap =
         expandedParent['@reverse'] = expandedParent['@reverse'] || {};
-      if(!_isArray(expandedValue)) {
-        expandedValue = [expandedValue];
-      }
+      expandedValue = _asArray(expandedValue);
       for(let ii = 0; ii < expandedValue.length; ++ii) {
         const item = expandedValue[ii];
         if(_isValue(item) || _isList(item)) {
@@ -809,7 +810,7 @@ function _expandLanguageMap(activeCtx, languageMap) {
         throw new JsonLdError(
           'Invalid JSON-LD syntax; language map values must be strings.',
           'jsonld.SyntaxError',
-          {code: 'invalid language map value', languageMap: languageMap});
+          {code: 'invalid language map value', languageMap});
       }
       const val = {'@value': item};
       if(expandedKey !== '@none') {
