@@ -28,7 +28,7 @@ module.exports = api;
 api.frameMergedOrDefault = (input, frame, options) => {
   // create framing state
   const state = {
-    options: options,
+    options,
     graph: '@default',
     graphMap: {'@default': {}},
     graphStack: [],
@@ -135,11 +135,11 @@ api.frame = (state, subjects, frame, parent, property = null) => {
         _removeEmbed(state, id);
       }
       state.uniqueEmbeds[state.graph][id] =
-        {parent: parent, property: property};
+        {parent, property};
     }
 
     // push matching subject onto stack to enable circular embed checks
-    state.subjectStack.push({subject: subject, graph: state.graph});
+    state.subjectStack.push({subject, graph: state.graph});
 
     // subject is also the name of a graph
     if(id in state.graphMap) {
@@ -358,7 +358,7 @@ function _validateFrame(frame) {
   if(!types.isArray(frame) || frame.length !== 1 || !types.isObject(frame[0])) {
     throw new JsonLdError(
       'Invalid JSON-LD syntax; a JSON-LD frame must be a single object.',
-      'jsonld.SyntaxError', {frame: frame});
+      'jsonld.SyntaxError', {frame});
   }
 }
 
