@@ -84,6 +84,7 @@ const _nodejs = (
 const _browser = !_nodejs &&
   (typeof window !== 'undefined' || typeof self !== 'undefined');
 
+/* eslint-disable indent */
 // attaches jsonld API to the given object
 const wrapper = function(jsonld) {
 
@@ -98,8 +99,8 @@ const wrapper = function(jsonld) {
  *          [base] the base IRI to use.
  *          [compactArrays] true to compact arrays to single values when
  *            appropriate, false not to (default: true).
- *          [compactToRelative] true to compact IRIs to be relative to document base,
- *            false to keep absolute (default: true)
+ *          [compactToRelative] true to compact IRIs to be relative to document
+ *            base, false to keep absolute (default: true)
  *          [graph] true to always output a top-level graph (default: false).
  *          [expandContext] a context to expand with.
  *          [skipExpansion] true to assume the input is expanded and skip
@@ -215,7 +216,9 @@ jsonld.compact = util.callbackify(async function(input, ctx, options) {
   // add context and/or @graph
   if(_isArray(compacted)) {
     // use '@graph' keyword
-    const graphAlias = _compactIri({activeCtx, iri: '@graph', relativeTo: {vocab: true}});
+    const graphAlias = _compactIri({
+      activeCtx, iri: '@graph', relativeTo: {vocab: true}
+    });
     const graph = compacted;
     compacted = {};
     if(hasContext) {
@@ -226,14 +229,16 @@ jsonld.compact = util.callbackify(async function(input, ctx, options) {
     // reorder keys so @context is first
     const graph = compacted;
     compacted = {'@context': ctx};
-    for(let key in graph) {
+    for(const key in graph) {
       compacted[key] = graph[key];
     }
   }
 
   if(options.framing) {
     // get graph alias
-    const graph = _compactIri({activeCtx, iri: '@graph', relativeTo: {vocab: true}});
+    const graph = _compactIri({
+      activeCtx, iri: '@graph', relativeTo: {vocab: true}
+    });
     // remove @preserve from results
     options.link = {};
     compacted[graph] = _removePreserve(activeCtx, compacted[graph], options);
@@ -447,7 +452,7 @@ jsonld.frame = util.callbackify(async function(input, frame, options) {
     }
   }
 
-  let frameContext = frame ? frame['@context'] || {} : {};
+  const frameContext = frame ? frame['@context'] || {} : {};
 
   // expand input
   const expanded = await jsonld.expand(input, options);
@@ -458,7 +463,8 @@ jsonld.frame = util.callbackify(async function(input, frame, options) {
   opts.keepFreeFloatingNodes = true;
   const expandedFrame = await jsonld.expand(frame, opts);
 
-  // if the unexpanded frame includes a key expanding to @graph, frame the default graph, otherwise, the merged graph
+  // if the unexpanded frame includes a key expanding to @graph, frame the
+  // default graph, otherwise, the merged graph
   let framed;
   // FIXME should look for aliases of @graph
   opts.merged = !('@graph' in frame);
@@ -511,7 +517,7 @@ jsonld.link = util.callbackify(async function(input, ctx, options) {
  *          the 'inputFormat' option.
  * @param [options] the options to use:
  *          [algorithm] the normalization algorithm to use, `URDNA2015` or
- *            `URGNA2012` (default: `URGNA2012`).
+ *            `URGNA2012` (default: `URDNA2015`).
  *          [base] the base IRI to use.
  *          [expandContext] a context to expand with.
  *          [skipExpansion] true to assume the input is expanded and skip
@@ -521,6 +527,7 @@ jsonld.link = util.callbackify(async function(input, ctx, options) {
  *          [format] the format if output is a string:
  *            'application/n-quads' for N-Quads.
  *          [documentLoader(url, callback(err, remoteDoc))] the document loader.
+ *          [useNative] true to use a native canonize algorithm
  * @param [callback(err, normalized)] called once the operation completes.
  *
  * @return a Promise that resolves to the normalized output.
@@ -783,14 +790,14 @@ jsonld.merge = util.callbackify(async function(docs, ctx, options) {
 
     if(_graphs !== graphs) {
       // merge document graphs but don't merge existing nodes
-      for(let graphName in _graphs) {
+      for(const graphName in _graphs) {
         const _nodeMap = _graphs[graphName];
         if(!(graphName in graphs)) {
           graphs[graphName] = _nodeMap;
           continue;
         }
         const nodeMap = graphs[graphName];
-        for(let key in _nodeMap) {
+        for(const key in _nodeMap) {
           if(!(key in nodeMap)) {
             nodeMap[key] = _nodeMap[key];
           }
@@ -845,7 +852,7 @@ jsonld.documentLoader = async url => {
   throw new JsonLdError(
     'Could not retrieve a JSON-LD document from the URL. URL ' +
     'dereferencing not implemented.', 'jsonld.LoadDocumentError',
-    {code: 'loading document failed', url: url});
+    {code: 'loading document failed', url});
 };
 
 /**
@@ -892,7 +899,7 @@ jsonld.get = util.callbackify(async function(url, options) {
       'jsonld.LoadDocumentError', {
         code: 'loading document failed',
         cause: e,
-        remoteDoc: remoteDoc
+        remoteDoc
       });
   }
 
@@ -928,7 +935,7 @@ jsonld.processContext = util.callbackify(async function(
   if(!(_isObject(localCtx) && '@context' in localCtx)) {
     localCtx = {'@context': localCtx};
   }
-  let ctx = await _getAllContexts(localCtx, options);
+  const ctx = await _getAllContexts(localCtx, options);
 
   return _processContext({activeCtx, localCtx: ctx, options});
 });
@@ -955,7 +962,7 @@ jsonld.useDocumentLoader = function(type) {
     throw new JsonLdError(
       'Unknown document loader type: "' + type + '"',
       'jsonld.UnknownDocumentLoader',
-      {type: type});
+      {type});
   }
 
   // set document loader
@@ -1047,10 +1054,6 @@ function _setDefaults(options, {
   documentLoader = jsonld.documentLoader,
   ...defaults
 }) {
-  if(typeof options === 'function') {
-    options = {};
-  }
-  options = options || {};
   return Object.assign({}, {documentLoader}, defaults, options);
 }
 
