@@ -6,6 +6,7 @@
  *
  * Copyright (c) 2011-2017 Digital Bazaar, Inc. All rights reserved.
  */
+/* eslint-disable indent */
 const EarlReport = require('./earl-report');
 const benchmark = require('benchmark');
 const join = require('join-path-js');
@@ -49,11 +50,17 @@ const TEST_TYPES = {
         // type set
         /^#t0104/,
         /^#t0105/,
+        // rel vocab
+        /^#t0107/,
         // html
         /^#th001/,
         /^#th002/,
         /^#th003/,
         /^#th004/,
+        // @type: @none
+        /^#ttn01/,
+        /^#ttn02/,
+        /^#ttn03/,
       ]
     },
     fn: 'compact',
@@ -93,6 +100,10 @@ const TEST_TYPES = {
         /^#t0012/,
         // iris
         /^#t0109/,
+        // rel vocab
+        /^#t0110/,
+        /^#t0111/,
+        /^#t0112/,
         // html
         /^#th001/,
         /^#th002/,
@@ -114,6 +125,17 @@ const TEST_TYPES = {
         /^#th020/,
         /^#th021/,
         /^#th022/,
+        // sealed
+        /^#tse01/,
+        /^#tse02/,
+        /^#tse03/,
+        /^#tse04/,
+        /^#tse05/,
+        /^#tse06/,
+        /^#tse08/,
+        /^#tse09/,
+        // @type: @none
+        /^#ttn02/,
       ]
     },
     fn: 'expand',
@@ -235,7 +257,7 @@ const TEST_TYPES = {
       readTestUrl('input'),
       createTestOptions({format: 'application/n-quads'})
     ],
-    compare: compareExpectedNQuads
+    compare: compareCanonizedExpectedNQuads
   },
   'rdfn:Urgna2012EvalTest': {
     fn: 'normalize',
@@ -270,7 +292,7 @@ if(options.earl && options.earl.filename) {
   options.earl.report = new EarlReport({id: options.earl.id});
 }
 
-return new Promise((resolve, reject) => {
+return new Promise(resolve => {
 
 // async generated tests
 // _tests => [{suite}, ...]
@@ -353,7 +375,7 @@ function addManifest(manifest, parent) {
     // resolve all entry promises and process
     Promise.all(entries).then(entries => {
       let p = Promise.resolve();
-      entries.forEach((entry) => {
+      entries.forEach(entry => {
         if(typeof entry === 'string' && entry.endsWith('js')) {
           // process later as a plain JavaScript file
           suite.imports.push(entry);
@@ -425,10 +447,10 @@ function addTest(manifest, test, tests) {
       // skip unknown and explicitly skipped test types
       const testTypes = Object.keys(TEST_TYPES);
       if(!isJsonLdType(test, testTypes) || isJsonLdType(test, SKIP_TESTS)) {
-        const type = [].concat(
-          getJsonLdValues(test, '@type'),
-          getJsonLdValues(test, 'type')
-        );
+        //const type = [].concat(
+        //  getJsonLdValues(test, '@type'),
+        //  getJsonLdValues(test, 'type')
+        //);
         //console.log('Skipping test "' + test.name + '" of type: ' + type);
         self.skip();
       }
@@ -493,14 +515,14 @@ function addTest(manifest, test, tests) {
       try {
         if(isJsonLdType(test, 'jld:NegativeEvaluationTest')) {
           await compareExpectedError(test, err);
-        } else if(isJsonLdType(test, 'jld:PositiveEvaluationTest')) {
+        } else if(isJsonLdType(test, 'jld:PositiveEvaluationTest') ||
+          isJsonLdType(test, 'rdfn:Urgna2012EvalTest') ||
+          isJsonLdType(test, 'rdfn:Urdna2015EvalTest')) {
           if(err) {
             throw err;
           }
           await testInfo.compare(test, result);
-        } else if(isJsonLdType(test, 'jld:PositiveSyntaxTest') ||
-          isJsonLdType(test, 'rdfn:Urgna2012EvalTest') ||
-          isJsonLdType(test, 'rdfn:Urdna2015EvalTest')) {
+        } else if(isJsonLdType(test, 'jld:PositiveSyntaxTest')) {
           // no checks
         } else {
           throw Error('Unknown test type: ' + test.type);
@@ -556,7 +578,7 @@ function addTest(manifest, test, tests) {
         }
         console.error('Error: ', JSON.stringify(err, null, 2));
         throw err;
-      };
+      }
     };
   }
 }
@@ -700,11 +722,26 @@ async function compareExpectedNQuads(test, result) {
   let expect;
   try {
     expect = await readTestNQuads(_getExpectProperty(test))(test);
-    let opts = {algorithm: 'URDNA2015'};
-    let expectDataset = rdfCanonize.NQuads.parse(expect);
-    let expectCmp = await rdfCanonize.canonize(expectDataset, opts);
-    let resultDataset = rdfCanonize.NQuads.parse(result);
-    let resultCmp = await rdfCanonize.canonize(resultDataset, opts);
+    assert.strictEqual(result, expect);
+  } catch(ex) {
+    if(options.bailOnError) {
+      console.log('\nTEST FAILED\n');
+      console.log('EXPECTED:\n' + expect);
+      console.log('ACTUAL:\n' + result);
+    }
+    throw ex;
+  }
+}
+
+async function compareCanonizedExpectedNQuads(test, result) {
+  let expect;
+  try {
+    expect = await readTestNQuads(_getExpectProperty(test))(test);
+    const opts = {algorithm: 'URDNA2015'};
+    const expectDataset = rdfCanonize.NQuads.parse(expect);
+    const expectCmp = await rdfCanonize.canonize(expectDataset, opts);
+    const resultDataset = rdfCanonize.NQuads.parse(result);
+    const resultCmp = await rdfCanonize.canonize(resultDataset, opts);
     assert.strictEqual(resultCmp, expectCmp);
   } catch(err) {
     if(options.bailOnError) {
@@ -898,7 +935,7 @@ function createDocumentLoader(test) {
       doc.document = json;
       return doc;
     }).catch(err => {
-      throw {name: 'loading document failed', url: url};
+      throw {name: 'loading document failed', url};
     });
   }
 }
